# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateLogAnalyticsLogGroupDetails(object):
    """
    Information about a new log group.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateLogAnalyticsLogGroupDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateLogAnalyticsLogGroupDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateLogAnalyticsLogGroupDetails.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateLogAnalyticsLogGroupDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateLogAnalyticsLogGroupDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateLogAnalyticsLogGroupDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateLogAnalyticsLogGroupDetails.
        A user-friendly name that is changeable and that does not have to be unique.
        Format: a leading alphanumeric, followed by zero or more
        alphanumerics, underscores, spaces, backslashes, or hyphens in any order).
        No trailing spaces allowed.


        :return: The display_name of this CreateLogAnalyticsLogGroupDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateLogAnalyticsLogGroupDetails.
        A user-friendly name that is changeable and that does not have to be unique.
        Format: a leading alphanumeric, followed by zero or more
        alphanumerics, underscores, spaces, backslashes, or hyphens in any order).
        No trailing spaces allowed.


        :param display_name: The display_name of this CreateLogAnalyticsLogGroupDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateLogAnalyticsLogGroupDetails.
        Description for this resource.


        :return: The description of this CreateLogAnalyticsLogGroupDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateLogAnalyticsLogGroupDetails.
        Description for this resource.


        :param description: The description of this CreateLogAnalyticsLogGroupDetails.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateLogAnalyticsLogGroupDetails.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateLogAnalyticsLogGroupDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateLogAnalyticsLogGroupDetails.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateLogAnalyticsLogGroupDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateLogAnalyticsLogGroupDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateLogAnalyticsLogGroupDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateLogAnalyticsLogGroupDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateLogAnalyticsLogGroupDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateLogAnalyticsLogGroupDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateLogAnalyticsLogGroupDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateLogAnalyticsLogGroupDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateLogAnalyticsLogGroupDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDatabaseWallet(object):
    """
    The Autonomous Database wallet details.
    """

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseWallet.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseWallet.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDatabaseWallet object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AutonomousDatabaseWallet.
            Allowed values for this property are: "ACTIVE", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_rotated:
            The value to assign to the time_rotated property of this AutonomousDatabaseWallet.
        :type time_rotated: datetime

        """
        self.swagger_types = {
            'lifecycle_state': 'str',
            'time_rotated': 'datetime'
        }

        self.attribute_map = {
            'lifecycle_state': 'lifecycleState',
            'time_rotated': 'timeRotated'
        }

        self._lifecycle_state = None
        self._time_rotated = None

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this AutonomousDatabaseWallet.
        The current lifecycle state of the Autonomous Database wallet.

        Allowed values for this property are: "ACTIVE", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AutonomousDatabaseWallet.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AutonomousDatabaseWallet.
        The current lifecycle state of the Autonomous Database wallet.


        :param lifecycle_state: The lifecycle_state of this AutonomousDatabaseWallet.
        :type: str
        """
        allowed_values = ["ACTIVE", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_rotated(self):
        """
        Gets the time_rotated of this AutonomousDatabaseWallet.
        The date and time the wallet was last rotated.


        :return: The time_rotated of this AutonomousDatabaseWallet.
        :rtype: datetime
        """
        return self._time_rotated

    @time_rotated.setter
    def time_rotated(self, time_rotated):
        """
        Sets the time_rotated of this AutonomousDatabaseWallet.
        The date and time the wallet was last rotated.


        :param time_rotated: The time_rotated of this AutonomousDatabaseWallet.
        :type: datetime
        """
        self._time_rotated = time_rotated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2018 Character Encoding Detector contributors.  https://github.com/chardet

from .charsetprober import CharSetProber
from .enums import ProbingState, MachineState
from .codingstatemachine import CodingStateMachine
from .mbcssm import UTF8_SM_MODEL



class UTF8Prober(CharSetProber):
    ONE_CHAR_PROB = 0.5

    def __init__(self):
        super(UTF8Prober, self).__init__()
        self.coding_sm = CodingStateMachine(UTF8_SM_MODEL)
        self._num_mb_chars = None
        self.reset()

    def reset(self):
        super(UTF8Prober, self).reset()
        self.coding_sm.reset()
        self._num_mb_chars = 0

    @property
    def charset_name(self):
        return "utf-8"

    @property
    def language(self):
        return ""

    def feed(self, byte_str):
        for c in byte_str:
            coding_state = self.coding_sm.next_state(c)
            if coding_state == MachineState.ERROR:
                self._state = ProbingState.NOT_ME
                break
            elif coding_state == MachineState.ITS_ME:
                self._state = ProbingState.FOUND_IT
                break
            elif coding_state == MachineState.START:
                if self.coding_sm.get_current_charlen() >= 2:
                    self._num_mb_chars += 1

        if self.state == ProbingState.DETECTING:
            if self.get_confidence() > self.SHORTCUT_THRESHOLD:
                self._state = ProbingState.FOUND_IT

        return self.state

    def get_confidence(self):
        unlike = 0.99
        if self._num_mb_chars < 6:
            unlike *= self.ONE_CHAR_PROB ** self._num_mb_chars
            return 1.0 - unlike
        else:
            return unlike



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .source_details import SourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LoggingSourceDetails(SourceDetails):
    """
    The logging source.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LoggingSourceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.sch.models.LoggingSourceDetails.kind` attribute
        of this class is ``logging`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this LoggingSourceDetails.
            Allowed values for this property are: "logging"
        :type kind: str

        :param log_sources:
            The value to assign to the log_sources property of this LoggingSourceDetails.
        :type log_sources: list[LogSource]

        """
        self.swagger_types = {
            'kind': 'str',
            'log_sources': 'list[LogSource]'
        }

        self.attribute_map = {
            'kind': 'kind',
            'log_sources': 'logSources'
        }

        self._kind = None
        self._log_sources = None
        self._kind = 'logging'

    @property
    def log_sources(self):
        """
        **[Required]** Gets the log_sources of this LoggingSourceDetails.
        The resources affected by this work request.


        :return: The log_sources of this LoggingSourceDetails.
        :rtype: list[LogSource]
        """
        return self._log_sources

    @log_sources.setter
    def log_sources(self, log_sources):
        """
        Sets the log_sources of this LoggingSourceDetails.
        The resources affected by this work request.


        :param log_sources: The log_sources of this LoggingSourceDetails.
        :type: list[LogSource]
        """
        self._log_sources = log_sources

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HealthCheck(object):
    """
    Health checks monitor the status of your origin servers and only route traffic to the origins that pass the health check. If the health check fails, origin is automatically removed from the load balancing.
    There is roughly one health check per EDGE POP per period. Any checks that pass will be reported as \"healthy\".
    """

    #: A constant which can be used with the method property of a HealthCheck.
    #: This constant has a value of "GET"
    METHOD_GET = "GET"

    #: A constant which can be used with the method property of a HealthCheck.
    #: This constant has a value of "HEAD"
    METHOD_HEAD = "HEAD"

    #: A constant which can be used with the method property of a HealthCheck.
    #: This constant has a value of "POST"
    METHOD_POST = "POST"

    #: A constant which can be used with the expected_response_code_group property of a HealthCheck.
    #: This constant has a value of "2XX"
    EXPECTED_RESPONSE_CODE_GROUP_2_XX = "2XX"

    #: A constant which can be used with the expected_response_code_group property of a HealthCheck.
    #: This constant has a value of "3XX"
    EXPECTED_RESPONSE_CODE_GROUP_3_XX = "3XX"

    #: A constant which can be used with the expected_response_code_group property of a HealthCheck.
    #: This constant has a value of "4XX"
    EXPECTED_RESPONSE_CODE_GROUP_4_XX = "4XX"

    #: A constant which can be used with the expected_response_code_group property of a HealthCheck.
    #: This constant has a value of "5XX"
    EXPECTED_RESPONSE_CODE_GROUP_5_XX = "5XX"

    def __init__(self, **kwargs):
        """
        Initializes a new HealthCheck object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_enabled:
            The value to assign to the is_enabled property of this HealthCheck.
        :type is_enabled: bool

        :param method:
            The value to assign to the method property of this HealthCheck.
            Allowed values for this property are: "GET", "HEAD", "POST", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type method: str

        :param path:
            The value to assign to the path property of this HealthCheck.
        :type path: str

        :param headers:
            The value to assign to the headers property of this HealthCheck.
        :type headers: dict(str, str)

        :param expected_response_code_group:
            The value to assign to the expected_response_code_group property of this HealthCheck.
            Allowed values for items in this list are: "2XX", "3XX", "4XX", "5XX", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type expected_response_code_group: list[str]

        :param is_response_text_check_enabled:
            The value to assign to the is_response_text_check_enabled property of this HealthCheck.
        :type is_response_text_check_enabled: bool

        :param expected_response_text:
            The value to assign to the expected_response_text property of this HealthCheck.
        :type expected_response_text: str

        :param interval_in_seconds:
            The value to assign to the interval_in_seconds property of this HealthCheck.
        :type interval_in_seconds: int

        :param timeout_in_seconds:
            The value to assign to the timeout_in_seconds property of this HealthCheck.
        :type timeout_in_seconds: int

        :param healthy_threshold:
            The value to assign to the healthy_threshold property of this HealthCheck.
        :type healthy_threshold: int

        :param unhealthy_threshold:
            The value to assign to the unhealthy_threshold property of this HealthCheck.
        :type unhealthy_threshold: int

        """
        self.swagger_types = {
            'is_enabled': 'bool',
            'method': 'str',
            'path': 'str',
            'headers': 'dict(str, str)',
            'expected_response_code_group': 'list[str]',
            'is_response_text_check_enabled': 'bool',
            'expected_response_text': 'str',
            'interval_in_seconds': 'int',
            'timeout_in_seconds': 'int',
            'healthy_threshold': 'int',
            'unhealthy_threshold': 'int'
        }

        self.attribute_map = {
            'is_enabled': 'isEnabled',
            'method': 'method',
            'path': 'path',
            'headers': 'headers',
            'expected_response_code_group': 'expectedResponseCodeGroup',
            'is_response_text_check_enabled': 'isResponseTextCheckEnabled',
            'expected_response_text': 'expectedResponseText',
            'interval_in_seconds': 'intervalInSeconds',
            'timeout_in_seconds': 'timeoutInSeconds',
            'healthy_threshold': 'healthyThreshold',
            'unhealthy_threshold': 'unhealthyThreshold'
        }

        self._is_enabled = None
        self._method = None
        self._path = None
        self._headers = None
        self._expected_response_code_group = None
        self._is_response_text_check_enabled = None
        self._expected_response_text = None
        self._interval_in_seconds = None
        self._timeout_in_seconds = None
        self._healthy_threshold = None
        self._unhealthy_threshold = None

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this HealthCheck.
        Enables or disables the health checks.


        :return: The is_enabled of this HealthCheck.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this HealthCheck.
        Enables or disables the health checks.


        :param is_enabled: The is_enabled of this HealthCheck.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def method(self):
        """
        Gets the method of this HealthCheck.
        An HTTP verb (i.e. HEAD, GET, or POST) to use when performing the health check.

        Allowed values for this property are: "GET", "HEAD", "POST", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The method of this HealthCheck.
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """
        Sets the method of this HealthCheck.
        An HTTP verb (i.e. HEAD, GET, or POST) to use when performing the health check.


        :param method: The method of this HealthCheck.
        :type: str
        """
        allowed_values = ["GET", "HEAD", "POST"]
        if not value_allowed_none_or_none_sentinel(method, allowed_values):
            method = 'UNKNOWN_ENUM_VALUE'
        self._method = method

    @property
    def path(self):
        """
        Gets the path of this HealthCheck.
        Path to visit on your origins when performing the health check.


        :return: The path of this HealthCheck.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this HealthCheck.
        Path to visit on your origins when performing the health check.


        :param path: The path of this HealthCheck.
        :type: str
        """
        self._path = path

    @property
    def headers(self):
        """
        Gets the headers of this HealthCheck.
        HTTP header fields to include in health check requests, expressed as `\"name\": \"value\"` properties. Because HTTP header field names are case-insensitive, any use of names that are case-insensitive equal to other names will be rejected. If Host is not specified, requests will include a Host header field with value matching the policy's protected domain. If User-Agent is not specified, requests will include a User-Agent header field with value \"waf health checks\".

        **Note:** The only currently-supported header fields are Host and User-Agent.


        :return: The headers of this HealthCheck.
        :rtype: dict(str, str)
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """
        Sets the headers of this HealthCheck.
        HTTP header fields to include in health check requests, expressed as `\"name\": \"value\"` properties. Because HTTP header field names are case-insensitive, any use of names that are case-insensitive equal to other names will be rejected. If Host is not specified, requests will include a Host header field with value matching the policy's protected domain. If User-Agent is not specified, requests will include a User-Agent header field with value \"waf health checks\".

        **Note:** The only currently-supported header fields are Host and User-Agent.


        :param headers: The headers of this HealthCheck.
        :type: dict(str, str)
        """
        self._headers = headers

    @property
    def expected_response_code_group(self):
        """
        Gets the expected_response_code_group of this HealthCheck.
        The HTTP response codes that signify a healthy state.
        - **2XX:** Success response code group.
        - **3XX:** Redirection response code group.
        - **4XX:** Client errors response code group.
        - **5XX:** Server errors response code group.

        Allowed values for items in this list are: "2XX", "3XX", "4XX", "5XX", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The expected_response_code_group of this HealthCheck.
        :rtype: list[str]
        """
        return self._expected_response_code_group

    @expected_response_code_group.setter
    def expected_response_code_group(self, expected_response_code_group):
        """
        Sets the expected_response_code_group of this HealthCheck.
        The HTTP response codes that signify a healthy state.
        - **2XX:** Success response code group.
        - **3XX:** Redirection response code group.
        - **4XX:** Client errors response code group.
        - **5XX:** Server errors response code group.


        :param expected_response_code_group: The expected_response_code_group of this HealthCheck.
        :type: list[str]
        """
        allowed_values = ["2XX", "3XX", "4XX", "5XX"]
        if expected_response_code_group:
            expected_response_code_group[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in expected_response_code_group]
        self._expected_response_code_group = expected_response_code_group

    @property
    def is_response_text_check_enabled(self):
        """
        Gets the is_response_text_check_enabled of this HealthCheck.
        Enables or disables additional check for predefined text in addition to response code.


        :return: The is_response_text_check_enabled of this HealthCheck.
        :rtype: bool
        """
        return self._is_response_text_check_enabled

    @is_response_text_check_enabled.setter
    def is_response_text_check_enabled(self, is_response_text_check_enabled):
        """
        Sets the is_response_text_check_enabled of this HealthCheck.
        Enables or disables additional check for predefined text in addition to response code.


        :param is_response_text_check_enabled: The is_response_text_check_enabled of this HealthCheck.
        :type: bool
        """
        self._is_response_text_check_enabled = is_response_text_check_enabled

    @property
    def expected_response_text(self):
        """
        Gets the expected_response_text of this HealthCheck.
        Health check will search for the given text in a case-sensitive manner within the response body and will fail if the text is not found.


        :return: The expected_response_text of this HealthCheck.
        :rtype: str
        """
        return self._expected_response_text

    @expected_response_text.setter
    def expected_response_text(self, expected_response_text):
        """
        Sets the expected_response_text of this HealthCheck.
        Health check will search for the given text in a case-sensitive manner within the response body and will fail if the text is not found.


        :param expected_response_text: The expected_response_text of this HealthCheck.
        :type: str
        """
        self._expected_response_text = expected_response_text

    @property
    def interval_in_seconds(self):
        """
        Gets the interval_in_seconds of this HealthCheck.
        Time between health checks of an individual origin server, in seconds.


        :return: The interval_in_seconds of this HealthCheck.
        :rtype: int
        """
        return self._interval_in_seconds

    @interval_in_seconds.setter
    def interval_in_seconds(self, interval_in_seconds):
        """
        Sets the interval_in_seconds of this HealthCheck.
        Time between health checks of an individual origin server, in seconds.


        :param interval_in_seconds: The interval_in_seconds of this HealthCheck.
        :type: int
        """
        self._interval_in_seconds = interval_in_seconds

    @property
    def timeout_in_seconds(self):
        """
        Gets the timeout_in_seconds of this HealthCheck.
        Response timeout represents wait time until request is considered failed, in seconds.


        :return: The timeout_in_seconds of this HealthCheck.
        :rtype: int
        """
        return self._timeout_in_seconds

    @timeout_in_seconds.setter
    def timeout_in_seconds(self, timeout_in_seconds):
        """
        Sets the timeout_in_seconds of this HealthCheck.
        Response timeout represents wait time until request is considered failed, in seconds.


        :param timeout_in_seconds: The timeout_in_seconds of this HealthCheck.
        :type: int
        """
        self._timeout_in_seconds = timeout_in_seconds

    @property
    def healthy_threshold(self):
        """
        Gets the healthy_threshold of this HealthCheck.
        Number of successful health checks after which the server is marked up.


        :return: The healthy_threshold of this HealthCheck.
        :rtype: int
        """
        return self._healthy_threshold

    @healthy_threshold.setter
    def healthy_threshold(self, healthy_threshold):
        """
        Sets the healthy_threshold of this HealthCheck.
        Number of successful health checks after which the server is marked up.


        :param healthy_threshold: The healthy_threshold of this HealthCheck.
        :type: int
        """
        self._healthy_threshold = healthy_threshold

    @property
    def unhealthy_threshold(self):
        """
        Gets the unhealthy_threshold of this HealthCheck.
        Number of failed health checks after which the server is marked down.


        :return: The unhealthy_threshold of this HealthCheck.
        :rtype: int
        """
        return self._unhealthy_threshold

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, unhealthy_threshold):
        """
        Sets the unhealthy_threshold of this HealthCheck.
        Number of failed health checks after which the server is marked down.


        :param unhealthy_threshold: The unhealthy_threshold of this HealthCheck.
        :type: int
        """
        self._unhealthy_threshold = unhealthy_threshold

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreatePreauthenticatedRequestDetails(object):
    """
    CreatePreauthenticatedRequestDetails model.
    """

    #: A constant which can be used with the access_type property of a CreatePreauthenticatedRequestDetails.
    #: This constant has a value of "ObjectRead"
    ACCESS_TYPE_OBJECT_READ = "ObjectRead"

    #: A constant which can be used with the access_type property of a CreatePreauthenticatedRequestDetails.
    #: This constant has a value of "ObjectWrite"
    ACCESS_TYPE_OBJECT_WRITE = "ObjectWrite"

    #: A constant which can be used with the access_type property of a CreatePreauthenticatedRequestDetails.
    #: This constant has a value of "ObjectReadWrite"
    ACCESS_TYPE_OBJECT_READ_WRITE = "ObjectReadWrite"

    #: A constant which can be used with the access_type property of a CreatePreauthenticatedRequestDetails.
    #: This constant has a value of "AnyObjectWrite"
    ACCESS_TYPE_ANY_OBJECT_WRITE = "AnyObjectWrite"

    def __init__(self, **kwargs):
        """
        Initializes a new CreatePreauthenticatedRequestDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreatePreauthenticatedRequestDetails.
        :type name: str

        :param object_name:
            The value to assign to the object_name property of this CreatePreauthenticatedRequestDetails.
        :type object_name: str

        :param access_type:
            The value to assign to the access_type property of this CreatePreauthenticatedRequestDetails.
            Allowed values for this property are: "ObjectRead", "ObjectWrite", "ObjectReadWrite", "AnyObjectWrite"
        :type access_type: str

        :param time_expires:
            The value to assign to the time_expires property of this CreatePreauthenticatedRequestDetails.
        :type time_expires: datetime

        """
        self.swagger_types = {
            'name': 'str',
            'object_name': 'str',
            'access_type': 'str',
            'time_expires': 'datetime'
        }

        self.attribute_map = {
            'name': 'name',
            'object_name': 'objectName',
            'access_type': 'accessType',
            'time_expires': 'timeExpires'
        }

        self._name = None
        self._object_name = None
        self._access_type = None
        self._time_expires = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreatePreauthenticatedRequestDetails.
        A user-specified name for the pre-authenticated request. Names can be helpful in managing pre-authenticated requests.


        :return: The name of this CreatePreauthenticatedRequestDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreatePreauthenticatedRequestDetails.
        A user-specified name for the pre-authenticated request. Names can be helpful in managing pre-authenticated requests.


        :param name: The name of this CreatePreauthenticatedRequestDetails.
        :type: str
        """
        self._name = name

    @property
    def object_name(self):
        """
        Gets the object_name of this CreatePreauthenticatedRequestDetails.
        The name of the object that is being granted access to by the pre-authenticated request. Avoid entering confidential
        information. The object name can be null and if so, the pre-authenticated request grants access to the entire bucket.


        :return: The object_name of this CreatePreauthenticatedRequestDetails.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this CreatePreauthenticatedRequestDetails.
        The name of the object that is being granted access to by the pre-authenticated request. Avoid entering confidential
        information. The object name can be null and if so, the pre-authenticated request grants access to the entire bucket.


        :param object_name: The object_name of this CreatePreauthenticatedRequestDetails.
        :type: str
        """
        self._object_name = object_name

    @property
    def access_type(self):
        """
        **[Required]** Gets the access_type of this CreatePreauthenticatedRequestDetails.
        The operation that can be performed on this resource.

        Allowed values for this property are: "ObjectRead", "ObjectWrite", "ObjectReadWrite", "AnyObjectWrite"


        :return: The access_type of this CreatePreauthenticatedRequestDetails.
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """
        Sets the access_type of this CreatePreauthenticatedRequestDetails.
        The operation that can be performed on this resource.


        :param access_type: The access_type of this CreatePreauthenticatedRequestDetails.
        :type: str
        """
        allowed_values = ["ObjectRead", "ObjectWrite", "ObjectReadWrite", "AnyObjectWrite"]
        if not value_allowed_none_or_none_sentinel(access_type, allowed_values):
            raise ValueError(
                "Invalid value for `access_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._access_type = access_type

    @property
    def time_expires(self):
        """
        **[Required]** Gets the time_expires of this CreatePreauthenticatedRequestDetails.
        The expiration date for the pre-authenticated request as per `RFC 3339`__.
        After this date the pre-authenticated request will no longer be valid.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_expires of this CreatePreauthenticatedRequestDetails.
        :rtype: datetime
        """
        return self._time_expires

    @time_expires.setter
    def time_expires(self, time_expires):
        """
        Sets the time_expires of this CreatePreauthenticatedRequestDetails.
        The expiration date for the pre-authenticated request as per `RFC 3339`__.
        After this date the pre-authenticated request will no longer be valid.

        __ https://tools.ietf.org/html/rfc3339


        :param time_expires: The time_expires of this CreatePreauthenticatedRequestDetails.
        :type: datetime
        """
        self._time_expires = time_expires

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RemotePeeringConnection(object):
    """
    A remote peering connection (RPC) is an object on a DRG that lets the VCN that is attached
    to the DRG peer with a VCN in a different region. *Peering* means that the two VCNs can
    communicate using private IP addresses, but without the traffic traversing the internet or
    routing through your on-premises network. For more information, see
    `VCN Peering`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you
    supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Network/Tasks/VCNpeering.htm
    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a RemotePeeringConnection.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a RemotePeeringConnection.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a RemotePeeringConnection.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a RemotePeeringConnection.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the peering_status property of a RemotePeeringConnection.
    #: This constant has a value of "INVALID"
    PEERING_STATUS_INVALID = "INVALID"

    #: A constant which can be used with the peering_status property of a RemotePeeringConnection.
    #: This constant has a value of "NEW"
    PEERING_STATUS_NEW = "NEW"

    #: A constant which can be used with the peering_status property of a RemotePeeringConnection.
    #: This constant has a value of "PENDING"
    PEERING_STATUS_PENDING = "PENDING"

    #: A constant which can be used with the peering_status property of a RemotePeeringConnection.
    #: This constant has a value of "PEERED"
    PEERING_STATUS_PEERED = "PEERED"

    #: A constant which can be used with the peering_status property of a RemotePeeringConnection.
    #: This constant has a value of "REVOKED"
    PEERING_STATUS_REVOKED = "REVOKED"

    def __init__(self, **kwargs):
        """
        Initializes a new RemotePeeringConnection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this RemotePeeringConnection.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this RemotePeeringConnection.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this RemotePeeringConnection.
        :type display_name: str

        :param drg_id:
            The value to assign to the drg_id property of this RemotePeeringConnection.
        :type drg_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this RemotePeeringConnection.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this RemotePeeringConnection.
        :type id: str

        :param is_cross_tenancy_peering:
            The value to assign to the is_cross_tenancy_peering property of this RemotePeeringConnection.
        :type is_cross_tenancy_peering: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this RemotePeeringConnection.
            Allowed values for this property are: "AVAILABLE", "PROVISIONING", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param peer_id:
            The value to assign to the peer_id property of this RemotePeeringConnection.
        :type peer_id: str

        :param peer_region_name:
            The value to assign to the peer_region_name property of this RemotePeeringConnection.
        :type peer_region_name: str

        :param peer_tenancy_id:
            The value to assign to the peer_tenancy_id property of this RemotePeeringConnection.
        :type peer_tenancy_id: str

        :param peering_status:
            The value to assign to the peering_status property of this RemotePeeringConnection.
            Allowed values for this property are: "INVALID", "NEW", "PENDING", "PEERED", "REVOKED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type peering_status: str

        :param time_created:
            The value to assign to the time_created property of this RemotePeeringConnection.
        :type time_created: datetime

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'drg_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'is_cross_tenancy_peering': 'bool',
            'lifecycle_state': 'str',
            'peer_id': 'str',
            'peer_region_name': 'str',
            'peer_tenancy_id': 'str',
            'peering_status': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'drg_id': 'drgId',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'is_cross_tenancy_peering': 'isCrossTenancyPeering',
            'lifecycle_state': 'lifecycleState',
            'peer_id': 'peerId',
            'peer_region_name': 'peerRegionName',
            'peer_tenancy_id': 'peerTenancyId',
            'peering_status': 'peeringStatus',
            'time_created': 'timeCreated'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._drg_id = None
        self._freeform_tags = None
        self._id = None
        self._is_cross_tenancy_peering = None
        self._lifecycle_state = None
        self._peer_id = None
        self._peer_region_name = None
        self._peer_tenancy_id = None
        self._peering_status = None
        self._time_created = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this RemotePeeringConnection.
        The OCID of the compartment that contains the RPC.


        :return: The compartment_id of this RemotePeeringConnection.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this RemotePeeringConnection.
        The OCID of the compartment that contains the RPC.


        :param compartment_id: The compartment_id of this RemotePeeringConnection.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this RemotePeeringConnection.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this RemotePeeringConnection.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this RemotePeeringConnection.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this RemotePeeringConnection.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this RemotePeeringConnection.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this RemotePeeringConnection.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this RemotePeeringConnection.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this RemotePeeringConnection.
        :type: str
        """
        self._display_name = display_name

    @property
    def drg_id(self):
        """
        **[Required]** Gets the drg_id of this RemotePeeringConnection.
        The OCID of the DRG that this RPC belongs to.


        :return: The drg_id of this RemotePeeringConnection.
        :rtype: str
        """
        return self._drg_id

    @drg_id.setter
    def drg_id(self, drg_id):
        """
        Sets the drg_id of this RemotePeeringConnection.
        The OCID of the DRG that this RPC belongs to.


        :param drg_id: The drg_id of this RemotePeeringConnection.
        :type: str
        """
        self._drg_id = drg_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this RemotePeeringConnection.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this RemotePeeringConnection.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this RemotePeeringConnection.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this RemotePeeringConnection.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this RemotePeeringConnection.
        The OCID of the RPC.


        :return: The id of this RemotePeeringConnection.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RemotePeeringConnection.
        The OCID of the RPC.


        :param id: The id of this RemotePeeringConnection.
        :type: str
        """
        self._id = id

    @property
    def is_cross_tenancy_peering(self):
        """
        **[Required]** Gets the is_cross_tenancy_peering of this RemotePeeringConnection.
        Whether the VCN at the other end of the peering is in a different tenancy.

        Example: `false`


        :return: The is_cross_tenancy_peering of this RemotePeeringConnection.
        :rtype: bool
        """
        return self._is_cross_tenancy_peering

    @is_cross_tenancy_peering.setter
    def is_cross_tenancy_peering(self, is_cross_tenancy_peering):
        """
        Sets the is_cross_tenancy_peering of this RemotePeeringConnection.
        Whether the VCN at the other end of the peering is in a different tenancy.

        Example: `false`


        :param is_cross_tenancy_peering: The is_cross_tenancy_peering of this RemotePeeringConnection.
        :type: bool
        """
        self._is_cross_tenancy_peering = is_cross_tenancy_peering

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this RemotePeeringConnection.
        The RPC's current lifecycle state.

        Allowed values for this property are: "AVAILABLE", "PROVISIONING", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this RemotePeeringConnection.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this RemotePeeringConnection.
        The RPC's current lifecycle state.


        :param lifecycle_state: The lifecycle_state of this RemotePeeringConnection.
        :type: str
        """
        allowed_values = ["AVAILABLE", "PROVISIONING", "TERMINATING", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def peer_id(self):
        """
        Gets the peer_id of this RemotePeeringConnection.
        If this RPC is peered, this value is the OCID of the other RPC.


        :return: The peer_id of this RemotePeeringConnection.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this RemotePeeringConnection.
        If this RPC is peered, this value is the OCID of the other RPC.


        :param peer_id: The peer_id of this RemotePeeringConnection.
        :type: str
        """
        self._peer_id = peer_id

    @property
    def peer_region_name(self):
        """
        Gets the peer_region_name of this RemotePeeringConnection.
        If this RPC is peered, this value is the region that contains the other RPC.

        Example: `us-ashburn-1`


        :return: The peer_region_name of this RemotePeeringConnection.
        :rtype: str
        """
        return self._peer_region_name

    @peer_region_name.setter
    def peer_region_name(self, peer_region_name):
        """
        Sets the peer_region_name of this RemotePeeringConnection.
        If this RPC is peered, this value is the region that contains the other RPC.

        Example: `us-ashburn-1`


        :param peer_region_name: The peer_region_name of this RemotePeeringConnection.
        :type: str
        """
        self._peer_region_name = peer_region_name

    @property
    def peer_tenancy_id(self):
        """
        Gets the peer_tenancy_id of this RemotePeeringConnection.
        If this RPC is peered, this value is the OCID of the other RPC's tenancy.


        :return: The peer_tenancy_id of this RemotePeeringConnection.
        :rtype: str
        """
        return self._peer_tenancy_id

    @peer_tenancy_id.setter
    def peer_tenancy_id(self, peer_tenancy_id):
        """
        Sets the peer_tenancy_id of this RemotePeeringConnection.
        If this RPC is peered, this value is the OCID of the other RPC's tenancy.


        :param peer_tenancy_id: The peer_tenancy_id of this RemotePeeringConnection.
        :type: str
        """
        self._peer_tenancy_id = peer_tenancy_id

    @property
    def peering_status(self):
        """
        **[Required]** Gets the peering_status of this RemotePeeringConnection.
        Whether the RPC is peered with another RPC. `NEW` means the RPC has not yet been
        peered. `PENDING` means the peering is being established. `REVOKED` means the
        RPC at the other end of the peering has been deleted.

        Allowed values for this property are: "INVALID", "NEW", "PENDING", "PEERED", "REVOKED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The peering_status of this RemotePeeringConnection.
        :rtype: str
        """
        return self._peering_status

    @peering_status.setter
    def peering_status(self, peering_status):
        """
        Sets the peering_status of this RemotePeeringConnection.
        Whether the RPC is peered with another RPC. `NEW` means the RPC has not yet been
        peered. `PENDING` means the peering is being established. `REVOKED` means the
        RPC at the other end of the peering has been deleted.


        :param peering_status: The peering_status of this RemotePeeringConnection.
        :type: str
        """
        allowed_values = ["INVALID", "NEW", "PENDING", "PEERED", "REVOKED"]
        if not value_allowed_none_or_none_sentinel(peering_status, allowed_values):
            peering_status = 'UNKNOWN_ENUM_VALUE'
        self._peering_status = peering_status

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this RemotePeeringConnection.
        The date and time the RPC was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this RemotePeeringConnection.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this RemotePeeringConnection.
        The date and time the RPC was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this RemotePeeringConnection.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OceInstanceSummary(object):
    """
    Summary of the OceInstance.
    """

    #: A constant which can be used with the instance_usage_type property of a OceInstanceSummary.
    #: This constant has a value of "PRIMARY"
    INSTANCE_USAGE_TYPE_PRIMARY = "PRIMARY"

    #: A constant which can be used with the instance_usage_type property of a OceInstanceSummary.
    #: This constant has a value of "NONPRIMARY"
    INSTANCE_USAGE_TYPE_NONPRIMARY = "NONPRIMARY"

    #: A constant which can be used with the instance_access_type property of a OceInstanceSummary.
    #: This constant has a value of "PUBLIC"
    INSTANCE_ACCESS_TYPE_PUBLIC = "PUBLIC"

    #: A constant which can be used with the instance_access_type property of a OceInstanceSummary.
    #: This constant has a value of "PRIVATE"
    INSTANCE_ACCESS_TYPE_PRIVATE = "PRIVATE"

    #: A constant which can be used with the instance_license_type property of a OceInstanceSummary.
    #: This constant has a value of "NEW"
    INSTANCE_LICENSE_TYPE_NEW = "NEW"

    #: A constant which can be used with the instance_license_type property of a OceInstanceSummary.
    #: This constant has a value of "BYOL"
    INSTANCE_LICENSE_TYPE_BYOL = "BYOL"

    #: A constant which can be used with the lifecycle_state property of a OceInstanceSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a OceInstanceSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a OceInstanceSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a OceInstanceSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a OceInstanceSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a OceInstanceSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new OceInstanceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this OceInstanceSummary.
        :type id: str

        :param guid:
            The value to assign to the guid property of this OceInstanceSummary.
        :type guid: str

        :param description:
            The value to assign to the description property of this OceInstanceSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this OceInstanceSummary.
        :type compartment_id: str

        :param name:
            The value to assign to the name property of this OceInstanceSummary.
        :type name: str

        :param tenancy_id:
            The value to assign to the tenancy_id property of this OceInstanceSummary.
        :type tenancy_id: str

        :param idcs_tenancy:
            The value to assign to the idcs_tenancy property of this OceInstanceSummary.
        :type idcs_tenancy: str

        :param tenancy_name:
            The value to assign to the tenancy_name property of this OceInstanceSummary.
        :type tenancy_name: str

        :param instance_usage_type:
            The value to assign to the instance_usage_type property of this OceInstanceSummary.
            Allowed values for this property are: "PRIMARY", "NONPRIMARY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type instance_usage_type: str

        :param object_storage_namespace:
            The value to assign to the object_storage_namespace property of this OceInstanceSummary.
        :type object_storage_namespace: str

        :param admin_email:
            The value to assign to the admin_email property of this OceInstanceSummary.
        :type admin_email: str

        :param upgrade_schedule:
            The value to assign to the upgrade_schedule property of this OceInstanceSummary.
        :type upgrade_schedule: str

        :param waf_primary_domain:
            The value to assign to the waf_primary_domain property of this OceInstanceSummary.
        :type waf_primary_domain: str

        :param instance_access_type:
            The value to assign to the instance_access_type property of this OceInstanceSummary.
            Allowed values for this property are: "PUBLIC", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type instance_access_type: str

        :param instance_license_type:
            The value to assign to the instance_license_type property of this OceInstanceSummary.
            Allowed values for this property are: "NEW", "BYOL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type instance_license_type: str

        :param time_created:
            The value to assign to the time_created property of this OceInstanceSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this OceInstanceSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this OceInstanceSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param state_message:
            The value to assign to the state_message property of this OceInstanceSummary.
        :type state_message: str

        :param service:
            The value to assign to the service property of this OceInstanceSummary.
        :type service: dict(str, object)

        :param freeform_tags:
            The value to assign to the freeform_tags property of this OceInstanceSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this OceInstanceSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'guid': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'name': 'str',
            'tenancy_id': 'str',
            'idcs_tenancy': 'str',
            'tenancy_name': 'str',
            'instance_usage_type': 'str',
            'object_storage_namespace': 'str',
            'admin_email': 'str',
            'upgrade_schedule': 'str',
            'waf_primary_domain': 'str',
            'instance_access_type': 'str',
            'instance_license_type': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'state_message': 'str',
            'service': 'dict(str, object)',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'guid': 'guid',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'name': 'name',
            'tenancy_id': 'tenancyId',
            'idcs_tenancy': 'idcsTenancy',
            'tenancy_name': 'tenancyName',
            'instance_usage_type': 'instanceUsageType',
            'object_storage_namespace': 'objectStorageNamespace',
            'admin_email': 'adminEmail',
            'upgrade_schedule': 'upgradeSchedule',
            'waf_primary_domain': 'wafPrimaryDomain',
            'instance_access_type': 'instanceAccessType',
            'instance_license_type': 'instanceLicenseType',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'state_message': 'stateMessage',
            'service': 'service',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._guid = None
        self._description = None
        self._compartment_id = None
        self._name = None
        self._tenancy_id = None
        self._idcs_tenancy = None
        self._tenancy_name = None
        self._instance_usage_type = None
        self._object_storage_namespace = None
        self._admin_email = None
        self._upgrade_schedule = None
        self._waf_primary_domain = None
        self._instance_access_type = None
        self._instance_license_type = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._state_message = None
        self._service = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this OceInstanceSummary.
        Unique identifier that is immutable on creation


        :return: The id of this OceInstanceSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OceInstanceSummary.
        Unique identifier that is immutable on creation


        :param id: The id of this OceInstanceSummary.
        :type: str
        """
        self._id = id

    @property
    def guid(self):
        """
        **[Required]** Gets the guid of this OceInstanceSummary.
        Unique GUID identifier that is immutable on creation


        :return: The guid of this OceInstanceSummary.
        :rtype: str
        """
        return self._guid

    @guid.setter
    def guid(self, guid):
        """
        Sets the guid of this OceInstanceSummary.
        Unique GUID identifier that is immutable on creation


        :param guid: The guid of this OceInstanceSummary.
        :type: str
        """
        self._guid = guid

    @property
    def description(self):
        """
        Gets the description of this OceInstanceSummary.
        OceInstance description, can be updated


        :return: The description of this OceInstanceSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OceInstanceSummary.
        OceInstance description, can be updated


        :param description: The description of this OceInstanceSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this OceInstanceSummary.
        Compartment Identifier


        :return: The compartment_id of this OceInstanceSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this OceInstanceSummary.
        Compartment Identifier


        :param compartment_id: The compartment_id of this OceInstanceSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this OceInstanceSummary.
        OceInstance Name


        :return: The name of this OceInstanceSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OceInstanceSummary.
        OceInstance Name


        :param name: The name of this OceInstanceSummary.
        :type: str
        """
        self._name = name

    @property
    def tenancy_id(self):
        """
        **[Required]** Gets the tenancy_id of this OceInstanceSummary.
        Tenancy Identifier


        :return: The tenancy_id of this OceInstanceSummary.
        :rtype: str
        """
        return self._tenancy_id

    @tenancy_id.setter
    def tenancy_id(self, tenancy_id):
        """
        Sets the tenancy_id of this OceInstanceSummary.
        Tenancy Identifier


        :param tenancy_id: The tenancy_id of this OceInstanceSummary.
        :type: str
        """
        self._tenancy_id = tenancy_id

    @property
    def idcs_tenancy(self):
        """
        **[Required]** Gets the idcs_tenancy of this OceInstanceSummary.
        IDCS Tenancy Identifier


        :return: The idcs_tenancy of this OceInstanceSummary.
        :rtype: str
        """
        return self._idcs_tenancy

    @idcs_tenancy.setter
    def idcs_tenancy(self, idcs_tenancy):
        """
        Sets the idcs_tenancy of this OceInstanceSummary.
        IDCS Tenancy Identifier


        :param idcs_tenancy: The idcs_tenancy of this OceInstanceSummary.
        :type: str
        """
        self._idcs_tenancy = idcs_tenancy

    @property
    def tenancy_name(self):
        """
        **[Required]** Gets the tenancy_name of this OceInstanceSummary.
        Tenancy Name


        :return: The tenancy_name of this OceInstanceSummary.
        :rtype: str
        """
        return self._tenancy_name

    @tenancy_name.setter
    def tenancy_name(self, tenancy_name):
        """
        Sets the tenancy_name of this OceInstanceSummary.
        Tenancy Name


        :param tenancy_name: The tenancy_name of this OceInstanceSummary.
        :type: str
        """
        self._tenancy_name = tenancy_name

    @property
    def instance_usage_type(self):
        """
        Gets the instance_usage_type of this OceInstanceSummary.
        Instance type based on its usage

        Allowed values for this property are: "PRIMARY", "NONPRIMARY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The instance_usage_type of this OceInstanceSummary.
        :rtype: str
        """
        return self._instance_usage_type

    @instance_usage_type.setter
    def instance_usage_type(self, instance_usage_type):
        """
        Sets the instance_usage_type of this OceInstanceSummary.
        Instance type based on its usage


        :param instance_usage_type: The instance_usage_type of this OceInstanceSummary.
        :type: str
        """
        allowed_values = ["PRIMARY", "NONPRIMARY"]
        if not value_allowed_none_or_none_sentinel(instance_usage_type, allowed_values):
            instance_usage_type = 'UNKNOWN_ENUM_VALUE'
        self._instance_usage_type = instance_usage_type

    @property
    def object_storage_namespace(self):
        """
        **[Required]** Gets the object_storage_namespace of this OceInstanceSummary.
        Object Storage Namespace of tenancy


        :return: The object_storage_namespace of this OceInstanceSummary.
        :rtype: str
        """
        return self._object_storage_namespace

    @object_storage_namespace.setter
    def object_storage_namespace(self, object_storage_namespace):
        """
        Sets the object_storage_namespace of this OceInstanceSummary.
        Object Storage Namespace of tenancy


        :param object_storage_namespace: The object_storage_namespace of this OceInstanceSummary.
        :type: str
        """
        self._object_storage_namespace = object_storage_namespace

    @property
    def admin_email(self):
        """
        **[Required]** Gets the admin_email of this OceInstanceSummary.
        Admin Email for Notification


        :return: The admin_email of this OceInstanceSummary.
        :rtype: str
        """
        return self._admin_email

    @admin_email.setter
    def admin_email(self, admin_email):
        """
        Sets the admin_email of this OceInstanceSummary.
        Admin Email for Notification


        :param admin_email: The admin_email of this OceInstanceSummary.
        :type: str
        """
        self._admin_email = admin_email

    @property
    def upgrade_schedule(self):
        """
        Gets the upgrade_schedule of this OceInstanceSummary.
        Upgrade schedule type representing service to be upgraded immediately whenever latest version is released
        or delay upgrade of the service to previous released version


        :return: The upgrade_schedule of this OceInstanceSummary.
        :rtype: str
        """
        return self._upgrade_schedule

    @upgrade_schedule.setter
    def upgrade_schedule(self, upgrade_schedule):
        """
        Sets the upgrade_schedule of this OceInstanceSummary.
        Upgrade schedule type representing service to be upgraded immediately whenever latest version is released
        or delay upgrade of the service to previous released version


        :param upgrade_schedule: The upgrade_schedule of this OceInstanceSummary.
        :type: str
        """
        self._upgrade_schedule = upgrade_schedule

    @property
    def waf_primary_domain(self):
        """
        Gets the waf_primary_domain of this OceInstanceSummary.
        Web Application Firewall(WAF) primary domain


        :return: The waf_primary_domain of this OceInstanceSummary.
        :rtype: str
        """
        return self._waf_primary_domain

    @waf_primary_domain.setter
    def waf_primary_domain(self, waf_primary_domain):
        """
        Sets the waf_primary_domain of this OceInstanceSummary.
        Web Application Firewall(WAF) primary domain


        :param waf_primary_domain: The waf_primary_domain of this OceInstanceSummary.
        :type: str
        """
        self._waf_primary_domain = waf_primary_domain

    @property
    def instance_access_type(self):
        """
        Gets the instance_access_type of this OceInstanceSummary.
        Flag indicating whether the instance access is private or public

        Allowed values for this property are: "PUBLIC", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The instance_access_type of this OceInstanceSummary.
        :rtype: str
        """
        return self._instance_access_type

    @instance_access_type.setter
    def instance_access_type(self, instance_access_type):
        """
        Sets the instance_access_type of this OceInstanceSummary.
        Flag indicating whether the instance access is private or public


        :param instance_access_type: The instance_access_type of this OceInstanceSummary.
        :type: str
        """
        allowed_values = ["PUBLIC", "PRIVATE"]
        if not value_allowed_none_or_none_sentinel(instance_access_type, allowed_values):
            instance_access_type = 'UNKNOWN_ENUM_VALUE'
        self._instance_access_type = instance_access_type

    @property
    def instance_license_type(self):
        """
        Gets the instance_license_type of this OceInstanceSummary.
        Flag indicating whether the instance license is new cloud or bring your own license

        Allowed values for this property are: "NEW", "BYOL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The instance_license_type of this OceInstanceSummary.
        :rtype: str
        """
        return self._instance_license_type

    @instance_license_type.setter
    def instance_license_type(self, instance_license_type):
        """
        Sets the instance_license_type of this OceInstanceSummary.
        Flag indicating whether the instance license is new cloud or bring your own license


        :param instance_license_type: The instance_license_type of this OceInstanceSummary.
        :type: str
        """
        allowed_values = ["NEW", "BYOL"]
        if not value_allowed_none_or_none_sentinel(instance_license_type, allowed_values):
            instance_license_type = 'UNKNOWN_ENUM_VALUE'
        self._instance_license_type = instance_license_type

    @property
    def time_created(self):
        """
        Gets the time_created of this OceInstanceSummary.
        The time the the OceInstance was created. An RFC3339 formatted datetime string


        :return: The time_created of this OceInstanceSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this OceInstanceSummary.
        The time the the OceInstance was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this OceInstanceSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this OceInstanceSummary.
        The time the OceInstance was updated. An RFC3339 formatted datetime string


        :return: The time_updated of this OceInstanceSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this OceInstanceSummary.
        The time the OceInstance was updated. An RFC3339 formatted datetime string


        :param time_updated: The time_updated of this OceInstanceSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this OceInstanceSummary.
        The current state of the file system.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this OceInstanceSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this OceInstanceSummary.
        The current state of the file system.


        :param lifecycle_state: The lifecycle_state of this OceInstanceSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def state_message(self):
        """
        Gets the state_message of this OceInstanceSummary.
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The state_message of this OceInstanceSummary.
        :rtype: str
        """
        return self._state_message

    @state_message.setter
    def state_message(self, state_message):
        """
        Sets the state_message of this OceInstanceSummary.
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param state_message: The state_message of this OceInstanceSummary.
        :type: str
        """
        self._state_message = state_message

    @property
    def service(self):
        """
        Gets the service of this OceInstanceSummary.
        SERVICE data.
        Example: `{\"service\": {\"IDCS\": \"value\"}}`


        :return: The service of this OceInstanceSummary.
        :rtype: dict(str, object)
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this OceInstanceSummary.
        SERVICE data.
        Example: `{\"service\": {\"IDCS\": \"value\"}}`


        :param service: The service of this OceInstanceSummary.
        :type: dict(str, object)
        """
        self._service = service

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this OceInstanceSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this OceInstanceSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this OceInstanceSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this OceInstanceSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this OceInstanceSummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this OceInstanceSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this OceInstanceSummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this OceInstanceSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TunnelStatus(object):
    """
    Deprecated. For tunnel information, instead see :class:`IPSecConnectionTunnel`.
    """

    #: A constant which can be used with the lifecycle_state property of a TunnelStatus.
    #: This constant has a value of "UP"
    LIFECYCLE_STATE_UP = "UP"

    #: A constant which can be used with the lifecycle_state property of a TunnelStatus.
    #: This constant has a value of "DOWN"
    LIFECYCLE_STATE_DOWN = "DOWN"

    #: A constant which can be used with the lifecycle_state property of a TunnelStatus.
    #: This constant has a value of "DOWN_FOR_MAINTENANCE"
    LIFECYCLE_STATE_DOWN_FOR_MAINTENANCE = "DOWN_FOR_MAINTENANCE"

    def __init__(self, **kwargs):
        """
        Initializes a new TunnelStatus object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ip_address:
            The value to assign to the ip_address property of this TunnelStatus.
        :type ip_address: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this TunnelStatus.
            Allowed values for this property are: "UP", "DOWN", "DOWN_FOR_MAINTENANCE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this TunnelStatus.
        :type time_created: datetime

        :param time_state_modified:
            The value to assign to the time_state_modified property of this TunnelStatus.
        :type time_state_modified: datetime

        """
        self.swagger_types = {
            'ip_address': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_state_modified': 'datetime'
        }

        self.attribute_map = {
            'ip_address': 'ipAddress',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_state_modified': 'timeStateModified'
        }

        self._ip_address = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_state_modified = None

    @property
    def ip_address(self):
        """
        **[Required]** Gets the ip_address of this TunnelStatus.
        The IP address of Oracle's VPN headend.

        Example: `203.0.113.50`


        :return: The ip_address of this TunnelStatus.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this TunnelStatus.
        The IP address of Oracle's VPN headend.

        Example: `203.0.113.50`


        :param ip_address: The ip_address of this TunnelStatus.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this TunnelStatus.
        The tunnel's current state.

        Allowed values for this property are: "UP", "DOWN", "DOWN_FOR_MAINTENANCE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this TunnelStatus.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this TunnelStatus.
        The tunnel's current state.


        :param lifecycle_state: The lifecycle_state of this TunnelStatus.
        :type: str
        """
        allowed_values = ["UP", "DOWN", "DOWN_FOR_MAINTENANCE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        Gets the time_created of this TunnelStatus.
        The date and time the IPSec connection was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this TunnelStatus.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this TunnelStatus.
        The date and time the IPSec connection was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this TunnelStatus.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_state_modified(self):
        """
        Gets the time_state_modified of this TunnelStatus.
        When the state of the tunnel last changed, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_state_modified of this TunnelStatus.
        :rtype: datetime
        """
        return self._time_state_modified

    @time_state_modified.setter
    def time_state_modified(self, time_state_modified):
        """
        Sets the time_state_modified of this TunnelStatus.
        When the state of the tunnel last changed, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_state_modified: The time_state_modified of this TunnelStatus.
        :type: datetime
        """
        self._time_state_modified = time_state_modified

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataFlowValidationSummary(object):
    """
    The information about dataflow validation
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataFlowValidationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total_message_count:
            The value to assign to the total_message_count property of this DataFlowValidationSummary.
        :type total_message_count: int

        :param error_message_count:
            The value to assign to the error_message_count property of this DataFlowValidationSummary.
        :type error_message_count: int

        :param warn_message_count:
            The value to assign to the warn_message_count property of this DataFlowValidationSummary.
        :type warn_message_count: int

        :param info_message_count:
            The value to assign to the info_message_count property of this DataFlowValidationSummary.
        :type info_message_count: int

        :param validation_messages:
            The value to assign to the validation_messages property of this DataFlowValidationSummary.
        :type validation_messages: dict(str, list[ValidationMessage])

        :param key:
            The value to assign to the key property of this DataFlowValidationSummary.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this DataFlowValidationSummary.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this DataFlowValidationSummary.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this DataFlowValidationSummary.
        :type parent_ref: ParentReference

        :param name:
            The value to assign to the name property of this DataFlowValidationSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this DataFlowValidationSummary.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this DataFlowValidationSummary.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this DataFlowValidationSummary.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this DataFlowValidationSummary.
        :type identifier: str

        :param metadata:
            The value to assign to the metadata property of this DataFlowValidationSummary.
        :type metadata: ObjectMetadata

        """
        self.swagger_types = {
            'total_message_count': 'int',
            'error_message_count': 'int',
            'warn_message_count': 'int',
            'info_message_count': 'int',
            'validation_messages': 'dict(str, list[ValidationMessage])',
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'metadata': 'ObjectMetadata'
        }

        self.attribute_map = {
            'total_message_count': 'totalMessageCount',
            'error_message_count': 'errorMessageCount',
            'warn_message_count': 'warnMessageCount',
            'info_message_count': 'infoMessageCount',
            'validation_messages': 'validationMessages',
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'metadata': 'metadata'
        }

        self._total_message_count = None
        self._error_message_count = None
        self._warn_message_count = None
        self._info_message_count = None
        self._validation_messages = None
        self._key = None
        self._model_type = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._metadata = None

    @property
    def total_message_count(self):
        """
        Gets the total_message_count of this DataFlowValidationSummary.
        Total number of validation messages


        :return: The total_message_count of this DataFlowValidationSummary.
        :rtype: int
        """
        return self._total_message_count

    @total_message_count.setter
    def total_message_count(self, total_message_count):
        """
        Sets the total_message_count of this DataFlowValidationSummary.
        Total number of validation messages


        :param total_message_count: The total_message_count of this DataFlowValidationSummary.
        :type: int
        """
        self._total_message_count = total_message_count

    @property
    def error_message_count(self):
        """
        Gets the error_message_count of this DataFlowValidationSummary.
        Total number of validation error messages


        :return: The error_message_count of this DataFlowValidationSummary.
        :rtype: int
        """
        return self._error_message_count

    @error_message_count.setter
    def error_message_count(self, error_message_count):
        """
        Sets the error_message_count of this DataFlowValidationSummary.
        Total number of validation error messages


        :param error_message_count: The error_message_count of this DataFlowValidationSummary.
        :type: int
        """
        self._error_message_count = error_message_count

    @property
    def warn_message_count(self):
        """
        Gets the warn_message_count of this DataFlowValidationSummary.
        Total number of validation warning messages


        :return: The warn_message_count of this DataFlowValidationSummary.
        :rtype: int
        """
        return self._warn_message_count

    @warn_message_count.setter
    def warn_message_count(self, warn_message_count):
        """
        Sets the warn_message_count of this DataFlowValidationSummary.
        Total number of validation warning messages


        :param warn_message_count: The warn_message_count of this DataFlowValidationSummary.
        :type: int
        """
        self._warn_message_count = warn_message_count

    @property
    def info_message_count(self):
        """
        Gets the info_message_count of this DataFlowValidationSummary.
        Total number of validation information messages


        :return: The info_message_count of this DataFlowValidationSummary.
        :rtype: int
        """
        return self._info_message_count

    @info_message_count.setter
    def info_message_count(self, info_message_count):
        """
        Sets the info_message_count of this DataFlowValidationSummary.
        Total number of validation information messages


        :param info_message_count: The info_message_count of this DataFlowValidationSummary.
        :type: int
        """
        self._info_message_count = info_message_count

    @property
    def validation_messages(self):
        """
        Gets the validation_messages of this DataFlowValidationSummary.
        Detailed information of the DataFlow object validation.


        :return: The validation_messages of this DataFlowValidationSummary.
        :rtype: dict(str, list[ValidationMessage])
        """
        return self._validation_messages

    @validation_messages.setter
    def validation_messages(self, validation_messages):
        """
        Sets the validation_messages of this DataFlowValidationSummary.
        Detailed information of the DataFlow object validation.


        :param validation_messages: The validation_messages of this DataFlowValidationSummary.
        :type: dict(str, list[ValidationMessage])
        """
        self._validation_messages = validation_messages

    @property
    def key(self):
        """
        Gets the key of this DataFlowValidationSummary.
        Objects will use a 36 character key as unique ID. It is system generated and cannot be edited by user


        :return: The key of this DataFlowValidationSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this DataFlowValidationSummary.
        Objects will use a 36 character key as unique ID. It is system generated and cannot be edited by user


        :param key: The key of this DataFlowValidationSummary.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this DataFlowValidationSummary.
        The type of the object.


        :return: The model_type of this DataFlowValidationSummary.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this DataFlowValidationSummary.
        The type of the object.


        :param model_type: The model_type of this DataFlowValidationSummary.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this DataFlowValidationSummary.
        The model version of an object.


        :return: The model_version of this DataFlowValidationSummary.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this DataFlowValidationSummary.
        The model version of an object.


        :param model_version: The model_version of this DataFlowValidationSummary.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this DataFlowValidationSummary.

        :return: The parent_ref of this DataFlowValidationSummary.
        :rtype: ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this DataFlowValidationSummary.

        :param parent_ref: The parent_ref of this DataFlowValidationSummary.
        :type: ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this DataFlowValidationSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :return: The name of this DataFlowValidationSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DataFlowValidationSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :param name: The name of this DataFlowValidationSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this DataFlowValidationSummary.
        Detailed description for the object.


        :return: The description of this DataFlowValidationSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DataFlowValidationSummary.
        Detailed description for the object.


        :param description: The description of this DataFlowValidationSummary.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this DataFlowValidationSummary.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this DataFlowValidationSummary.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this DataFlowValidationSummary.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this DataFlowValidationSummary.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this DataFlowValidationSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this DataFlowValidationSummary.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this DataFlowValidationSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this DataFlowValidationSummary.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this DataFlowValidationSummary.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :return: The identifier of this DataFlowValidationSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this DataFlowValidationSummary.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :param identifier: The identifier of this DataFlowValidationSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def metadata(self):
        """
        Gets the metadata of this DataFlowValidationSummary.

        :return: The metadata of this DataFlowValidationSummary.
        :rtype: ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this DataFlowValidationSummary.

        :param metadata: The metadata of this DataFlowValidationSummary.
        :type: ObjectMetadata
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .log_entry import LogEntry
from .log_entry_batch import LogEntryBatch
from .put_logs_details import PutLogsDetails

# Maps type names to classes for loggingingestion services.
loggingingestion_type_mapping = {
    "LogEntry": LogEntry,
    "LogEntryBatch": LogEntryBatch,
    "PutLogsDetails": PutLogsDetails
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ClientOptions(object):
    """
    NFS export options applied to a specified set of
    clients. Only governs access through the associated
    export. Access to the same file system through a different
    export (on the same or different mount target) will be governed
    by that export's export options.
    """

    #: A constant which can be used with the access property of a ClientOptions.
    #: This constant has a value of "READ_WRITE"
    ACCESS_READ_WRITE = "READ_WRITE"

    #: A constant which can be used with the access property of a ClientOptions.
    #: This constant has a value of "READ_ONLY"
    ACCESS_READ_ONLY = "READ_ONLY"

    #: A constant which can be used with the identity_squash property of a ClientOptions.
    #: This constant has a value of "NONE"
    IDENTITY_SQUASH_NONE = "NONE"

    #: A constant which can be used with the identity_squash property of a ClientOptions.
    #: This constant has a value of "ROOT"
    IDENTITY_SQUASH_ROOT = "ROOT"

    #: A constant which can be used with the identity_squash property of a ClientOptions.
    #: This constant has a value of "ALL"
    IDENTITY_SQUASH_ALL = "ALL"

    def __init__(self, **kwargs):
        """
        Initializes a new ClientOptions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this ClientOptions.
        :type source: str

        :param require_privileged_source_port:
            The value to assign to the require_privileged_source_port property of this ClientOptions.
        :type require_privileged_source_port: bool

        :param access:
            The value to assign to the access property of this ClientOptions.
            Allowed values for this property are: "READ_WRITE", "READ_ONLY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type access: str

        :param identity_squash:
            The value to assign to the identity_squash property of this ClientOptions.
            Allowed values for this property are: "NONE", "ROOT", "ALL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type identity_squash: str

        :param anonymous_uid:
            The value to assign to the anonymous_uid property of this ClientOptions.
        :type anonymous_uid: int

        :param anonymous_gid:
            The value to assign to the anonymous_gid property of this ClientOptions.
        :type anonymous_gid: int

        """
        self.swagger_types = {
            'source': 'str',
            'require_privileged_source_port': 'bool',
            'access': 'str',
            'identity_squash': 'str',
            'anonymous_uid': 'int',
            'anonymous_gid': 'int'
        }

        self.attribute_map = {
            'source': 'source',
            'require_privileged_source_port': 'requirePrivilegedSourcePort',
            'access': 'access',
            'identity_squash': 'identitySquash',
            'anonymous_uid': 'anonymousUid',
            'anonymous_gid': 'anonymousGid'
        }

        self._source = None
        self._require_privileged_source_port = None
        self._access = None
        self._identity_squash = None
        self._anonymous_uid = None
        self._anonymous_gid = None

    @property
    def source(self):
        """
        **[Required]** Gets the source of this ClientOptions.
        Clients these options should apply to. Must be a either
        single IPv4 address or single IPv4 CIDR block.

        **Note:** Access will also be limited by any applicable VCN
        security rules and the ability to route IP packets to the
        mount target. Mount targets do not have Internet-routable IP addresses.


        :return: The source of this ClientOptions.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this ClientOptions.
        Clients these options should apply to. Must be a either
        single IPv4 address or single IPv4 CIDR block.

        **Note:** Access will also be limited by any applicable VCN
        security rules and the ability to route IP packets to the
        mount target. Mount targets do not have Internet-routable IP addresses.


        :param source: The source of this ClientOptions.
        :type: str
        """
        self._source = source

    @property
    def require_privileged_source_port(self):
        """
        Gets the require_privileged_source_port of this ClientOptions.
        If `true`, clients accessing the file system through this
        export must connect from a privileged source port. If
        unspecified, defaults to `true`.


        :return: The require_privileged_source_port of this ClientOptions.
        :rtype: bool
        """
        return self._require_privileged_source_port

    @require_privileged_source_port.setter
    def require_privileged_source_port(self, require_privileged_source_port):
        """
        Sets the require_privileged_source_port of this ClientOptions.
        If `true`, clients accessing the file system through this
        export must connect from a privileged source port. If
        unspecified, defaults to `true`.


        :param require_privileged_source_port: The require_privileged_source_port of this ClientOptions.
        :type: bool
        """
        self._require_privileged_source_port = require_privileged_source_port

    @property
    def access(self):
        """
        Gets the access of this ClientOptions.
        Type of access to grant clients using the file system
        through this export. If unspecified defaults to `READ_ONLY`.

        Allowed values for this property are: "READ_WRITE", "READ_ONLY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The access of this ClientOptions.
        :rtype: str
        """
        return self._access

    @access.setter
    def access(self, access):
        """
        Sets the access of this ClientOptions.
        Type of access to grant clients using the file system
        through this export. If unspecified defaults to `READ_ONLY`.


        :param access: The access of this ClientOptions.
        :type: str
        """
        allowed_values = ["READ_WRITE", "READ_ONLY"]
        if not value_allowed_none_or_none_sentinel(access, allowed_values):
            access = 'UNKNOWN_ENUM_VALUE'
        self._access = access

    @property
    def identity_squash(self):
        """
        Gets the identity_squash of this ClientOptions.
        Used when clients accessing the file system through this export
        have their UID and GID remapped to 'anonymousUid' and
        'anonymousGid'. If `ALL`, all users and groups are remapped;
        if `ROOT`, only the root user and group (UID/GID 0) are
        remapped; if `NONE`, no remapping is done. If unspecified,
        defaults to `ROOT`.

        Allowed values for this property are: "NONE", "ROOT", "ALL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The identity_squash of this ClientOptions.
        :rtype: str
        """
        return self._identity_squash

    @identity_squash.setter
    def identity_squash(self, identity_squash):
        """
        Sets the identity_squash of this ClientOptions.
        Used when clients accessing the file system through this export
        have their UID and GID remapped to 'anonymousUid' and
        'anonymousGid'. If `ALL`, all users and groups are remapped;
        if `ROOT`, only the root user and group (UID/GID 0) are
        remapped; if `NONE`, no remapping is done. If unspecified,
        defaults to `ROOT`.


        :param identity_squash: The identity_squash of this ClientOptions.
        :type: str
        """
        allowed_values = ["NONE", "ROOT", "ALL"]
        if not value_allowed_none_or_none_sentinel(identity_squash, allowed_values):
            identity_squash = 'UNKNOWN_ENUM_VALUE'
        self._identity_squash = identity_squash

    @property
    def anonymous_uid(self):
        """
        Gets the anonymous_uid of this ClientOptions.
        UID value to remap to when squashing a client UID (see
        identitySquash for more details.) If unspecified, defaults
        to `65534`.


        :return: The anonymous_uid of this ClientOptions.
        :rtype: int
        """
        return self._anonymous_uid

    @anonymous_uid.setter
    def anonymous_uid(self, anonymous_uid):
        """
        Sets the anonymous_uid of this ClientOptions.
        UID value to remap to when squashing a client UID (see
        identitySquash for more details.) If unspecified, defaults
        to `65534`.


        :param anonymous_uid: The anonymous_uid of this ClientOptions.
        :type: int
        """
        self._anonymous_uid = anonymous_uid

    @property
    def anonymous_gid(self):
        """
        Gets the anonymous_gid of this ClientOptions.
        GID value to remap to when squashing a client GID (see
        identitySquash for more details.) If unspecified defaults
        to `65534`.


        :return: The anonymous_gid of this ClientOptions.
        :rtype: int
        """
        return self._anonymous_gid

    @anonymous_gid.setter
    def anonymous_gid(self, anonymous_gid):
        """
        Sets the anonymous_gid of this ClientOptions.
        GID value to remap to when squashing a client GID (see
        identitySquash for more details.) If unspecified defaults
        to `65534`.


        :param anonymous_gid: The anonymous_gid of this ClientOptions.
        :type: int
        """
        self._anonymous_gid = anonymous_gid

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .action_details import ActionDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateStreamingServiceActionDetails(ActionDetails):
    """
    Create an action that delivers to an Oracle Stream Service stream.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateStreamingServiceActionDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.events.models.CreateStreamingServiceActionDetails.action_type` attribute
        of this class is ``OSS`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action_type:
            The value to assign to the action_type property of this CreateStreamingServiceActionDetails.
            Allowed values for this property are: "ONS", "OSS", "FAAS"
        :type action_type: str

        :param is_enabled:
            The value to assign to the is_enabled property of this CreateStreamingServiceActionDetails.
        :type is_enabled: bool

        :param description:
            The value to assign to the description property of this CreateStreamingServiceActionDetails.
        :type description: str

        :param stream_id:
            The value to assign to the stream_id property of this CreateStreamingServiceActionDetails.
        :type stream_id: str

        """
        self.swagger_types = {
            'action_type': 'str',
            'is_enabled': 'bool',
            'description': 'str',
            'stream_id': 'str'
        }

        self.attribute_map = {
            'action_type': 'actionType',
            'is_enabled': 'isEnabled',
            'description': 'description',
            'stream_id': 'streamId'
        }

        self._action_type = None
        self._is_enabled = None
        self._description = None
        self._stream_id = None
        self._action_type = 'OSS'

    @property
    def stream_id(self):
        """
        **[Required]** Gets the stream_id of this CreateStreamingServiceActionDetails.
        The `OCID`__ of the stream to which messages are delivered.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The stream_id of this CreateStreamingServiceActionDetails.
        :rtype: str
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        """
        Sets the stream_id of this CreateStreamingServiceActionDetails.
        The `OCID`__ of the stream to which messages are delivered.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param stream_id: The stream_id of this CreateStreamingServiceActionDetails.
        :type: str
        """
        self._stream_id = stream_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConsoleConnection(object):
    """
    ConsoleConnection model.
    """

    #: A constant which can be used with the lifecycle_state property of a ConsoleConnection.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ConsoleConnection.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ConsoleConnection.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ConsoleConnection.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ConsoleConnection.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new ConsoleConnection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ConsoleConnection.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ConsoleConnection.
        :type compartment_id: str

        :param db_node_id:
            The value to assign to the db_node_id property of this ConsoleConnection.
        :type db_node_id: str

        :param connection_string:
            The value to assign to the connection_string property of this ConsoleConnection.
        :type connection_string: str

        :param fingerprint:
            The value to assign to the fingerprint property of this ConsoleConnection.
        :type fingerprint: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ConsoleConnection.
            Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'db_node_id': 'str',
            'connection_string': 'str',
            'fingerprint': 'str',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'db_node_id': 'dbNodeId',
            'connection_string': 'connectionString',
            'fingerprint': 'fingerprint',
            'lifecycle_state': 'lifecycleState'
        }

        self._id = None
        self._compartment_id = None
        self._db_node_id = None
        self._connection_string = None
        self._fingerprint = None
        self._lifecycle_state = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ConsoleConnection.
        The OCID of the console connection.


        :return: The id of this ConsoleConnection.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConsoleConnection.
        The OCID of the console connection.


        :param id: The id of this ConsoleConnection.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ConsoleConnection.
        The OCID of the compartment to contain the console connection.


        :return: The compartment_id of this ConsoleConnection.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ConsoleConnection.
        The OCID of the compartment to contain the console connection.


        :param compartment_id: The compartment_id of this ConsoleConnection.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def db_node_id(self):
        """
        **[Required]** Gets the db_node_id of this ConsoleConnection.
        The OCID of the database node.


        :return: The db_node_id of this ConsoleConnection.
        :rtype: str
        """
        return self._db_node_id

    @db_node_id.setter
    def db_node_id(self, db_node_id):
        """
        Sets the db_node_id of this ConsoleConnection.
        The OCID of the database node.


        :param db_node_id: The db_node_id of this ConsoleConnection.
        :type: str
        """
        self._db_node_id = db_node_id

    @property
    def connection_string(self):
        """
        **[Required]** Gets the connection_string of this ConsoleConnection.
        The SSH connection string for the console connection.


        :return: The connection_string of this ConsoleConnection.
        :rtype: str
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """
        Sets the connection_string of this ConsoleConnection.
        The SSH connection string for the console connection.


        :param connection_string: The connection_string of this ConsoleConnection.
        :type: str
        """
        self._connection_string = connection_string

    @property
    def fingerprint(self):
        """
        **[Required]** Gets the fingerprint of this ConsoleConnection.
        The SSH public key fingerprint for the console connection.


        :return: The fingerprint of this ConsoleConnection.
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """
        Sets the fingerprint of this ConsoleConnection.
        The SSH public key fingerprint for the console connection.


        :param fingerprint: The fingerprint of this ConsoleConnection.
        :type: str
        """
        self._fingerprint = fingerprint

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ConsoleConnection.
        The current state of the console connection.

        Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ConsoleConnection.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ConsoleConnection.
        The current state of the console connection.


        :param lifecycle_state: The lifecycle_state of this ConsoleConnection.
        :type: str
        """
        allowed_values = ["ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LabelPriority(object):
    """
    Label Priority
    """

    #: A constant which can be used with the priority property of a LabelPriority.
    #: This constant has a value of "NONE"
    PRIORITY_NONE = "NONE"

    #: A constant which can be used with the priority property of a LabelPriority.
    #: This constant has a value of "LOW"
    PRIORITY_LOW = "LOW"

    #: A constant which can be used with the priority property of a LabelPriority.
    #: This constant has a value of "MEDIUM"
    PRIORITY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the priority property of a LabelPriority.
    #: This constant has a value of "HIGH"
    PRIORITY_HIGH = "HIGH"

    def __init__(self, **kwargs):
        """
        Initializes a new LabelPriority object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param priority:
            The value to assign to the priority property of this LabelPriority.
            Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type priority: str

        """
        self.swagger_types = {
            'priority': 'str'
        }

        self.attribute_map = {
            'priority': 'priority'
        }

        self._priority = None

    @property
    def priority(self):
        """
        Gets the priority of this LabelPriority.
        tag priority

        Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The priority of this LabelPriority.
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this LabelPriority.
        tag priority


        :param priority: The priority of this LabelPriority.
        :type: str
        """
        allowed_values = ["NONE", "LOW", "MEDIUM", "HIGH"]
        if not value_allowed_none_or_none_sentinel(priority, allowed_values):
            priority = 'UNKNOWN_ENUM_VALUE'
        self._priority = priority

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
